#[repr(u8)]pub enum Cmd {
Show 17 variants
EOR = 239,
SE = 240,
NOP = 241,
DM = 242,
Break = 243,
IP = 244,
AO = 245,
AYT = 246,
EC = 247,
EL = 248,
GA = 249,
SB = 250,
WILL = 251,
WONT = 252,
DO = 253,
DONT = 254,
IAC = 255,
}Expand description
A telnet command.
Variants
EOR = 239
End of Record
SE = 240
End of subnegotiation parameters.
NOP = 241
No operation.
DM = 242
Data Mark. The data stream portion of a Synch. This should always be accompanied by a TCP Urgent notification.
Break = 243
NVT character BRK.
IP = 244
The function IP.
AO = 245
The function AO.
AYT = 246
The function AYT.
EC = 247
The function EC.
EL = 248
The function EL.
GA = 249
The GA signal.
SB = 250
Indicates that what follows is subnegotiation of the indicated option.
WILL = 251
Indicates the desire to begin performing, or confirmation that you are now performing, the indicated option.
WONT = 252
Indicates the refusal to perform, or continue performing, the indicated option.
DO = 253
Indicates the request that the other party perform, or confirmation that you are expecting the other party to perform, the indicated option.
DONT = 254
Indicates the demand that the other party stop performing, or confirmation that you are no longer expecting the other party to perform, the indicated option.
IAC = 255
Data Byte 255.